.. _misc_examples:

Miscellaneous Examples
----------------------

This is a collection of examples showing features of mritwin, particularly the generation of motion patterns and gradient system responses.